@@ -6,6 +6,7 @@ from typing import Optional
 
 import colander
 import deform
+from kerno.peto import Peto
 from kerno.state import to_dict
 from kerno.web.pyramid import kerno_view, IKerno
 from pyramid.decorator import reify
@@ -13,15 +14,13 @@ from pyramid.httpexceptions import HTTPFound, HTTPNotFound
 from pyramid.security import remember, forget, Authenticated
 from pyramid.settings import asbool
 from pyramid.url import route_url
-from pyramid_mailer import get_mailer
-from pyramid_mailer.message import Message
 
 from pluserable import const
 from pluserable.actions import (
     ActivateUser,
     CheckCredentials,
+    create_activation,
     require_activation_setting_value,
-    get_activation_link,
 )
 from pluserable.interfaces import (
     ILoginForm,
@@ -39,7 +38,7 @@ from pluserable.events import (
     NewRegistrationEvent,
     RegistrationActivatedEvent,
     PasswordResetEvent,
-    ProfileUpdatedEvent,
+    EventProfileUpdated,
 )
 from pluserable.exceptions import AuthenticationFailure, FormValidationFailure
 from pluserable.httpexceptions import HTTPBadRequest
@@ -97,36 +96,6 @@ def authenticated(request, userid) -> HTTPFound:
     )
 
 
-def create_activation(request, user):  # TODO Move to action
-    """Associate ``user`` with a new activation or keep the existing one.
-
-    Also send an email message to ``user`` with the link for her to click.
-    """
-    if user.activation is None:
-        kerno = request.registry.getUtility(IKerno)
-        Activation = kerno.utilities[const.ACTIVATION_CLASS]
-        activation = Activation()
-
-        repo = request.repo
-        repo.store_activation(activation)
-        user.activation = activation
-        repo.flush()
-
-    strings = get_strings(kerno)
-    message = Message(
-        subject=strings.activation_email_subject,
-        recipients=[user.email],
-        body=strings.activation_email_plain.replace(
-            "ACTIVATION_LINK",
-            get_activation_link(
-                request, user_id=user.id, code=user.activation.code
-            ),
-        ),
-    )
-    mailer = get_mailer(request)
-    mailer.send(message)
-
-
 def render_form(request, form, appstruct=None, **kw):
     settings = request.registry.settings
     retail = asbool(settings.get("pluserable.deform_retail", False))
@@ -206,7 +175,7 @@ class AuthView(BaseView):
             raise HTTPBadRequest({"invalid": e.asdict()})
 
         try:
-            ret = CheckCredentials.from_pyramid(self.request)(
+            ret = CheckCredentials(peto=Peto.from_pyramid(self.request))(
                 handle=captured["handle"], password=captured["password"]
             )
         except AuthenticationFailure as e:
@@ -233,7 +202,7 @@ class AuthView(BaseView):
                 return e.result(request)
 
             try:
-                ret = CheckCredentials.from_pyramid(request)(
+                ret = CheckCredentials(peto=Peto.from_pyramid(request))(
                     handle=captured["handle"], password=captured["password"]
                 )
             except AuthenticationFailure as e:  # TODO View for this exception
@@ -259,6 +228,7 @@ class AuthView(BaseView):
 
 
 class ForgotPasswordView(BaseView):
+
     def __init__(self, request):  # noqa
         super(ForgotPasswordView, self).__init__(request)
 
@@ -304,24 +274,11 @@ class ForgotPasswordView(BaseView):
             user.activation = activation
             repo.flush()  # initialize activation.code
 
-        # TODO: Generate msg in a separate method so subclasses can override
-        mailer = get_mailer(request)
-        username = (
-            getattr(user, "short_name", "")
-            or getattr(user, "full_name", "")
-            or getattr(user, "username", "")
-            or user.email
-        )
-        body = self.strings.reset_password_email_body.format(
-            link=route_url(
-                "reset_password", request, code=user.activation.code
-            ),
-            username=username,
-            domain=request.application_url,
-        )
-        subject = self.strings.reset_password_email_subject
-        message = Message(subject=subject, recipients=[user.email], body=body)
-        mailer.send(message)
+        # The app can replace the function that sends the email message.
+        send_reset_password_email = request.kerno.utilities[
+            "pluserable.send_reset_password_email"
+        ]
+        send_reset_password_email(request, user)
 
         request.add_flash(
             plain=self.strings.reset_password_email_sent, level="success"
@@ -337,12 +294,12 @@ class ForgotPasswordView(BaseView):
 
         # Ensure the code in the URL brings us a real activation object
         code = request.matchdict.get("code", None)
-        activation = request.repo.q_activation_by_code(code)
+        activation = request.repo.get_activation_by_code(code)
         if not activation:
             raise HTTPNotFound(self.strings.activation_code_not_found)
 
         # Ensure the activation is connected to a user. TODO fix
-        user = request.repo.q_user_by_activation(activation)
+        user = request.repo.get_user_by_activation(activation)
         if user is None:
             raise RuntimeError(
                 "How is it possible that I found the activation "
@@ -457,13 +414,13 @@ class RegisterView(BaseView):
         # This generic method must work with any custom User class and any
         # custom registration form:
         user = self.User(**controls)
-        self.request.repo.store_user(user)
+        self.request.repo.add(user)
         return user
 
     @kerno_view
     def activate(self):  # http://localhost:6543/activate/10/89008993e9d5
         request = self.request
-        ret = ActivateUser.from_pyramid(request)(
+        ret = ActivateUser(peto=Peto.from_pyramid(request))(
             code=request.matchdict.get("code", None),
             user_id=request.matchdict.get("user_id", None),
         )
@@ -482,7 +439,7 @@ class ProfileView(BaseView):
     def profile(self):
         """Display a user profile."""
         user_id = self.request.matchdict.get("user_id", None)
-        user = self.request.repo.q_user_by_id(user_id)
+        user = self.request.repo.get_user_by_id(user_id)
         if not user:
             raise HTTPNotFound()
         return {"user": user}
@@ -521,6 +478,7 @@ class ProfileView(BaseView):
                 else:
                     return e.result(request)
 
+            old_email = user.email
             changed = False
             email = captured.get("email", None)
             if email:
@@ -545,12 +503,17 @@ class ProfileView(BaseView):
                 changed = True
 
             if changed:
+                request.kerno.events.broadcast(
+                    EventProfileUpdated(
+                        request=request,
+                        user=user,
+                        values=captured,
+                        old_email=old_email,
+                    )
+                )
                 request.add_flash(
                     plain=self.strings.edit_profile_done, level="success"
                 )
-                request.registry.notify(
-                    ProfileUpdatedEvent(request, user, captured)
-                )
             return HTTPFound(location=request.url)
 
 
