@@ -1,7 +1,7 @@
 """Tests for the views."""
 
 from datetime import datetime
-from mock import Mock, patch
+from unittest.mock import Mock, patch
 
 from kerno.state import MalbonaRezulto
 from pyramid_mailer.interfaces import IMailer
@@ -9,18 +9,24 @@ from pyramid_mailer.mailer import DummyMailer
 from pyramid.httpexceptions import HTTPNotFound
 
 from pluserable.events import (
-    NewRegistrationEvent, PasswordResetEvent, ProfileUpdatedEvent)
+    NewRegistrationEvent,
+    PasswordResetEvent,
+    EventProfileUpdated,
+)
 from pluserable.interfaces import ILoginForm, ILoginSchema
 from pluserable.strings import UIStringsBase
 from pluserable.views import (
-    AuthView, ForgotPasswordView, ProfileView, RegisterView)
+    AuthView,
+    ForgotPasswordView,
+    ProfileView,
+    RegisterView,
+)
 
 from tests.models import User
 from tests.integration import IntegrationTestBase
 
 
 class TestAuthView(IntegrationTestBase):  # noqa
-
     def test_auth_view_extensions(self):  # noqa
         request = self.get_request()
 
@@ -37,21 +43,21 @@ class TestAuthView(IntegrationTestBase):  # noqa
         assert form.called
 
     def test_login_loads(self):  # noqa
-        self.config.registry.settings['pluserable.login_redirect'] = 'index'
-        self.config.registry.settings['pluserable.logout_redirect'] = 'index'
-        self.config.add_route('index', '/')
+        self.config.registry.settings["pluserable.login_redirect"] = "index"
+        self.config.registry.settings["pluserable.logout_redirect"] = "index"
+        self.config.add_route("index", "/")
 
         request = self.get_request()
         request.user = None
         view = AuthView(request)
         response = view.login()
 
-        assert response.get('form', None)
+        assert response.get("form", None)
 
     def test_login_redirects_if_logged_in(self):  # noqa
-        self.config.registry.settings['pluserable.login_redirect'] = 'index'
-        self.config.registry.settings['pluserable.logout_redirect'] = 'index'
-        self.config.add_route('index', '/')
+        self.config.registry.settings["pluserable.login_redirect"] = "index"
+        self.config.registry.settings["pluserable.logout_redirect"] = "index"
+        self.config.add_route("index", "/")
 
         request = self.get_request()
         request.user = Mock()
@@ -62,58 +68,68 @@ class TestAuthView(IntegrationTestBase):  # noqa
 
     def test_login_fails_empty(self):
         """Make sure we can't log in with empty credentials."""
-        self.config.add_route('index', '/')
-        self.config.registry.settings['pluserable.login_redirect'] = 'index'
-        self.config.registry.settings['pluserable.logout_redirect'] = 'index'
+        self.config.add_route("index", "/")
+        self.config.registry.settings["pluserable.login_redirect"] = "index"
+        self.config.registry.settings["pluserable.logout_redirect"] = "index"
 
-        request = self.get_request(post={
-            'submit': True,
-            'csrf_token': 'irrelevant but required',
-        }, request_method='POST')
+        request = self.get_request(
+            post={
+                "submit": True,
+                "csrf_token": "irrelevant but required",
+            },
+            request_method="POST",
+        )
         request.add_flash = Mock()
 
         view = AuthView(request)
         response = view.login()
-        errors = response['errors']
+        errors = response["errors"]
 
-        assert errors[0].node.name == 'handle'
-        assert errors[0].msg == 'Required'
-        assert errors[1].node.name == 'password'
-        assert errors[1].msg == 'Required'
+        assert errors[0].node.name == "handle"
+        assert errors[0].msg == "Required"
+        assert errors[1].node.name == "password"
+        assert errors[1].msg == "Required"
 
     def test_login_fails_bad_credentials(self):
         """Make sure we can't log in with bad credentials."""
-        self.config.registry.settings['pluserable.login_redirect'] = 'index'
-        self.config.registry.settings['pluserable.logout_redirect'] = 'index'
-        self.config.add_route('index', '/')
+        self.config.registry.settings["pluserable.login_redirect"] = "index"
+        self.config.registry.settings["pluserable.logout_redirect"] = "index"
+        self.config.add_route("index", "/")
 
-        request = self.get_request(post={
-            'submit': True,
-            'handle': 'admin',
-            'password': 'test123',
-            'csrf_token': 'irrelevant but required',
-        }, request_method='POST')
+        request = self.get_request(
+            post={
+                "submit": True,
+                "handle": "admin",
+                "password": "test123",
+                "csrf_token": "irrelevant but required",
+            },
+            request_method="POST",
+        )
         request.add_flash = Mock()
 
         view = AuthView(request)
         view.login()
         request.add_flash.assert_called_with(
-            plain="Wrong username or password.", level="danger")
+            plain="Wrong username or password.", level="danger"
+        )
 
     def test_login_succeeds(self):
         """Make sure we can log in."""
-        self.config.registry.settings['pluserable.login_redirect'] = 'index'
-        self.config.registry.settings['pluserable.logout_redirect'] = 'index'
-        self.config.add_route('index', '/')
+        self.config.registry.settings["pluserable.login_redirect"] = "index"
+        self.config.registry.settings["pluserable.logout_redirect"] = "index"
+        self.config.add_route("index", "/")
         user = self.create_users(count=1)
         self.sas.flush()
 
-        request = self.get_request(post={
-                'submit': True,
-                'handle': user.username,
-                'password': 'science',
-                'csrf_token': 'irrelevant but required',
-            }, request_method='POST')
+        request = self.get_request(
+            post={
+                "submit": True,
+                "handle": user.username,
+                "password": "science",
+                "csrf_token": "irrelevant but required",
+            },
+            request_method="POST",
+        )
         request.add_flash = Mock()
 
         view = AuthView(request)
@@ -124,32 +140,36 @@ class TestAuthView(IntegrationTestBase):  # noqa
 
     def test_inactive_login_fails(self):
         """Ensure we can't log in with an inactive user."""
-        self.config.registry.settings['pluserable.login_redirect'] = 'index'
-        self.config.registry.settings['pluserable.logout_redirect'] = 'index'
-        self.config.add_route('index', '/')
+        self.config.registry.settings["pluserable.login_redirect"] = "index"
+        self.config.registry.settings["pluserable.logout_redirect"] = "index"
+        self.config.add_route("index", "/")
 
         user = self.create_users(count=1, activation=True)
         self.sas.flush()
 
-        request = self.get_request(post={
-            'submit': True,
-            'handle': user.username,
-            'password': 'science',
-            'csrf_token': 'irrelevant but required',
-            }, request_method='POST')
+        request = self.get_request(
+            post={
+                "submit": True,
+                "handle": user.username,
+                "password": "science",
+                "csrf_token": "irrelevant but required",
+            },
+            request_method="POST",
+        )
         request.add_flash = Mock()
 
         view = AuthView(request)
         view.login()
         request.add_flash.assert_called_with(
-            plain='Your account is not active; please check your e-mail.',
-            level='danger')
+            plain="Your account is not active; please check your e-mail.",
+            level="danger",
+        )
 
     def test_logout(self):
         """User logs out successfully."""
-        self.config.registry.settings['pluserable.login_redirect'] = 'index'
-        self.config.registry.settings['pluserable.logout_redirect'] = 'index'
-        self.config.add_route('index', '/')
+        self.config.registry.settings["pluserable.login_redirect"] = "index"
+        self.config.registry.settings["pluserable.logout_redirect"] = "index"
+        self.config.add_route("index", "/")
         request = self.get_request()
 
         invalidate = Mock()
@@ -159,12 +179,12 @@ class TestAuthView(IntegrationTestBase):  # noqa
         request.session.invalidate = invalidate
 
         view = AuthView(request)
-        with patch('pluserable.views.forget') as forget:
-            with patch('pluserable.views.HTTPFound') as HTTPFound:
+        with patch("pluserable.views.forget") as forget:
+            with patch("pluserable.views.HTTPFound") as HTTPFound:
                 view.logout()
                 request.add_flash.assert_called_with(
-                    plain=UIStringsBase.logout_done,
-                    level="success")
+                    plain=UIStringsBase.logout_done, level="success"
+                )
 
                 forget.assert_called_with(request)
                 assert invalidate.called
@@ -172,23 +192,22 @@ class TestAuthView(IntegrationTestBase):  # noqa
 
 
 class TestRegisterView(IntegrationTestBase):  # noqa
-
     def test_register_loads_not_logged_in(self):  # noqa
         self.config.registry.registerUtility(DummyMailer(), IMailer)
-        self.config.add_route('index', '/')
+        self.config.add_route("index", "/")
 
         request = self.get_request()
         request.user = None
         view = RegisterView(request)
         response = view.register()
 
-        assert response.get('form', None)
+        assert response.get("form", None)
 
     def test_register_redirects_if_logged_in(self):  # noqa
-        self.config.registry.settings['pluserable.login_redirect'] = 'index'
-        self.config.registry.settings['pluserable.logout_redirect'] = 'index'
+        self.config.registry.settings["pluserable.login_redirect"] = "index"
+        self.config.registry.settings["pluserable.logout_redirect"] = "index"
         self.config.registry.registerUtility(DummyMailer(), IMailer)
-        self.config.add_route('index', '/')
+        self.config.add_route("index", "/")
 
         request = self.get_request()
         request.user = Mock()
@@ -199,78 +218,88 @@ class TestRegisterView(IntegrationTestBase):  # noqa
 
     def test_register_creates_inactive_user(self):  # noqa
         self.config.registry.registerUtility(DummyMailer(), IMailer)
-        self.config.add_route('index', '/')
+        self.config.add_route("index", "/")
 
-        request = self.get_request(post={
-            'username': 'admin',
-            'password': {
-                'password': 'test123',
-                'password-confirm': 'test123',
+        request = self.get_request(
+            post={
+                "username": "admin",
+                "password": {
+                    "password": "test123",
+                    "password-confirm": "test123",
+                },
+                "email": "carlsagan@nasa.gov",
+                "csrf_token": "irrelevant but required",
             },
-            'email': 'carlsagan@nasa.gov',
-            'csrf_token': 'irrelevant but required',
-        }, request_method='POST')
+            request_method="POST",
+        )
         request.add_flash = Mock()
         request.user = Mock()
         view = RegisterView(request)
         response = view.register()
 
         assert response.status_int == 302
-        user = request.repo.q_user_by_username('admin')
+        user = request.repo.get_user_by_username("admin")
         assert isinstance(user, User)
         assert not user.is_activated
 
     def test_register_validation(self):  # noqa
         self.config.registry.registerUtility(DummyMailer(), IMailer)
-        self.config.add_route('index', '/')
+        self.config.add_route("index", "/")
 
-        request = self.get_request(request_method='POST')
+        request = self.get_request(request_method="POST")
         request.user = Mock()
         view = RegisterView(request)
         response = view.register()
 
-        assert len(response['errors']) == 3
-        assert 'There was a problem with your submission' in response['form']
+        assert len(response["errors"]) == 3
+        assert "There was a problem with your submission" in response["form"]
 
     def test_register_existing_user(self):  # noqa
         self.config.registry.registerUtility(DummyMailer(), IMailer)
-        self.config.add_route('index', '/')
+        self.config.add_route("index", "/")
         user = self.create_users(count=1)
         self.sas.flush()
 
-        request = self.get_request(post={
-            'username': user.username,
-            'password': {
-                'password': 'science',
-                'password-confirm': 'science',
+        request = self.get_request(
+            post={
+                "username": user.username,
+                "password": {
+                    "password": "science",
+                    "password-confirm": "science",
+                },
+                "email": "carlsagan@nasa.gov",
             },
-            'email': 'carlsagan@nasa.gov'
-        }, request_method='POST')
+            request_method="POST",
+        )
 
         view = RegisterView(request)
         adict = view.register()
         assert isinstance(adict, dict)
-        assert adict['errors']
+        assert adict["errors"]
 
-    @patch('pluserable.views.require_activation_setting_value')
+    @patch("pluserable.views.require_activation_setting_value")
     def test_register_no_activation_suceeds(self, get_setting_mock):
         """Test register() with setting to not require activation."""
         get_setting_mock.return_value = False
-        self.config.add_route('index', '/')
+        self.config.add_route("index", "/")
 
         def handle_registration(event):
             event.request.repo.flush()
+
         self.config.add_subscriber(handle_registration, NewRegistrationEvent)
 
-        request = self.get_request(post={
-            'username': 'admin',
-            'password': {
-                'password': 'test123',
-                'password-confirm': 'test123',
+        request = self.get_request(
+            post={
+                "username": "admin",
+                "password": {
+                    "password": "test123",
+                    "password-confirm": "test123",
+                },
+                "email": "carlsagan@nasa.gov",
+                "csrf_token": "irrelevant but required",
             },
-            'email': 'carlsagan@nasa.gov',
-            'csrf_token': 'irrelevant but required',
-        }, request_method='POST')
+            request_method="POST",
+        )
 
         request.add_flash = Mock()
         request.user = Mock()
@@ -278,13 +307,14 @@ class TestRegisterView(IntegrationTestBase):  # noqa
         view = RegisterView(request)
         response = view.register()
         request.add_flash.assert_called_with(
-            plain=UIStringsBase.registration_done, level="success")
+            plain=UIStringsBase.registration_done, level="success"
+        )
         assert response.status_int == 302
-        user = request.repo.q_user_by_username('admin')
+        user = request.repo.get_user_by_username("admin")
         assert user.is_activated is True
 
     def test_registration_craps_out(self):  # noqa
-        self.config.add_route('index', '/')
+        self.config.add_route("index", "/")
 
         def send(message):
             raise Exception("I broke!")
@@ -293,22 +323,25 @@ class TestRegisterView(IntegrationTestBase):  # noqa
         mailer.send = send
         self.config.registry.registerUtility(mailer, IMailer)
 
-        request = self.get_request(post={
-            'username': 'admin',
-            'password': {
-                'password': 'test123',
-                'password-confirm': 'test123',
+        request = self.get_request(
+            post={
+                "username": "admin",
+                "password": {
+                    "password": "test123",
+                    "password-confirm": "test123",
+                },
+                "email": "carlsagan@nasa.gov",
+                "csrf_token": "irrelevant but required",
             },
-            'email': 'carlsagan@nasa.gov',
-            'csrf_token': 'irrelevant but required',
-        }, request_method='POST')
+            request_method="POST",
+        )
         view = RegisterView(request)
 
         self.assertRaises(Exception, view.register)
 
     def test_activate(self):  # noqa
         self.config.registry.registerUtility(DummyMailer(), IMailer)
-        self.config.add_route('index', '/')
+        self.config.add_route("index", "/")
 
         user = self.create_users(count=1, activation=True)
         self.sas.flush()
@@ -318,7 +351,7 @@ class TestRegisterView(IntegrationTestBase):  # noqa
         request.matchdict = Mock()
 
         def get(key, default):
-            if key == 'code':
+            if key == "code":
                 return user.activation.code
             else:
                 return user.id
@@ -327,7 +360,7 @@ class TestRegisterView(IntegrationTestBase):  # noqa
 
         view = RegisterView(request)
         response = view.activate()
-        the_user = request.repo.q_user_by_username(user.username)
+        the_user = request.repo.get_user_by_username(user.username)
 
         assert the_user is user
         assert the_user.activation is None
@@ -336,13 +369,13 @@ class TestRegisterView(IntegrationTestBase):  # noqa
 
     def test_activation_works(self):  # noqa
         self.config.registry.registerUtility(DummyMailer(), IMailer)
-        self.config.add_route('index', '/')
+        self.config.add_route("index", "/")
 
         user1, user2 = self.create_users(count=2, activation=True)
         self.sas.flush()
 
         def get(key, default):
-            if key == 'code':
+            if key == "code":
                 return user1.activation.code
             else:
                 return user1.id
@@ -361,7 +394,7 @@ class TestRegisterView(IntegrationTestBase):  # noqa
         assert response.status_int == 302
 
     def test_activate_invalid_code_raises(self):  # noqa
-        self.config.add_route('index', '/')
+        self.config.add_route("index", "/")
 
         self.config.registry.registerUtility(DummyMailer(), IMailer)
 
@@ -372,21 +405,21 @@ class TestRegisterView(IntegrationTestBase):  # noqa
         request.add_flash = Mock()
         request.matchdict = Mock()
         get = Mock()
-        get.return_value = 'invalid'
+        get.return_value = "invalid"
         request.matchdict.get = get
 
         view = RegisterView(request)
         with self.assertRaises(MalbonaRezulto):
             view.activate()
 
-        the_user = request.repo.q_user_by_username(user.username)
+        the_user = request.repo.get_user_by_username(user.username)
         assert the_user is user
         assert not the_user.is_activated
 
     def test_activate_invalid_user_raises(self):
         """One user tries to get activated with another's code."""
         self.config.registry.registerUtility(DummyMailer(), IMailer)
-        self.config.add_route('index', '/')
+        self.config.add_route("index", "/")
 
         user1, user2 = self.create_users(count=2, activation=True)
         self.sas.flush()
@@ -395,9 +428,9 @@ class TestRegisterView(IntegrationTestBase):  # noqa
         request.matchdict = Mock()
 
         def get(val, ret):
-            if val == 'code':
+            if val == "code":
                 return user2.activation.code
-            elif val == 'user_id':
+            elif val == "user_id":
                 return user1.id
 
         request.matchdict.get = get
@@ -406,24 +439,23 @@ class TestRegisterView(IntegrationTestBase):  # noqa
         with self.assertRaises(MalbonaRezulto):
             view.activate()
 
-        for user in request.repo.q_users():
+        for user in (user1, user2):
             assert not user.is_activated
 
 
 class TestForgotPasswordView(IntegrationTestBase):  # noqa
-
     def test_forgot_password_loads(self):  # noqa
-        self.config.add_route('index', '/')
+        self.config.add_route("index", "/")
 
         request = self.get_request()
         request.user = None
         view = ForgotPasswordView(request)
         response = view.forgot_password()
 
-        assert response.get('form', None)
+        assert response.get("form", None)
 
     def test_forgot_password_logged_in_redirects(self):  # noqa
-        self.config.add_route('index', '/')
+        self.config.add_route("index", "/")
 
         request = self.get_request()
         request.user = Mock()
@@ -433,16 +465,19 @@ class TestForgotPasswordView(IntegrationTestBase):  # noqa
         assert response.status_int == 302
 
     def test_forgot_password_valid_user_succeeds(self):  # noqa
-        self.config.add_route('index', '/')
+        self.config.add_route("index", "/")
         self.config.registry.registerUtility(DummyMailer(), IMailer)
 
         self.create_users(count=1)
         self.sas.flush()
 
-        request = self.get_request(post={
-            'email': 'carlsagan1@nasa.gov',
-            'csrf_token': 'irrelevant but required',
-        }, request_method='POST')
+        request = self.get_request(
+            post={
+                "email": "carlsagan1@nasa.gov",
+                "csrf_token": "irrelevant but required",
+            },
+            request_method="POST",
+        )
         request.add_flash = Mock()
         request.user = None
 
@@ -450,31 +485,34 @@ class TestForgotPasswordView(IntegrationTestBase):  # noqa
         response = view.forgot_password()
 
         request.add_flash.assert_called_with(
-            plain=UIStringsBase.reset_password_email_sent,
-            level="success")
+            plain=UIStringsBase.reset_password_email_sent, level="success"
+        )
         assert response.status_int == 302
 
     def test_forgot_password_invalid_password(self):  # noqa
-        self.config.add_route('index', '/')
+        self.config.add_route("index", "/")
         self.config.registry.registerUtility(DummyMailer(), IMailer)
 
         self.create_users(count=1)
         self.sas.flush()
 
-        request = self.get_request(post={
-            'email': 'sagan',
-            'csrf_token': 'irrelevant but required',
-        }, request_method='POST')
+        request = self.get_request(
+            post={
+                "email": "sagan",
+                "csrf_token": "irrelevant but required",
+            },
+            request_method="POST",
+        )
 
         request.user = None
 
         view = ForgotPasswordView(request)
         response = view.forgot_password()
 
-        assert len(response['errors']) == 1
+        assert len(response["errors"]) == 1
 
     def test_reset_password_loads(self):  # noqa
-        self.config.add_route('index', '/')
+        self.config.add_route("index", "/")
         self.config.registry.registerUtility(DummyMailer(), IMailer)
 
         user = self.create_users(count=1, activation=True)
@@ -492,23 +530,26 @@ class TestForgotPasswordView(IntegrationTestBase):  # noqa
         view = ForgotPasswordView(request)
         response = view.reset_password()
 
-        assert response.get('form', None)
-        assert 'sagan' in response['form']
+        assert response.get("form", None)
+        assert "sagan" in response["form"]
 
     def test_reset_password_valid_user(self):  # noqa
-        self.config.add_route('index', '/')
+        self.config.add_route("index", "/")
         self.config.registry.registerUtility(DummyMailer(), IMailer)
 
         user = self.create_users(count=1, activation=True)
         self.sas.flush()
 
-        request = self.get_request(post={
-            'password': {
-                'password': 'test123',
-                'password-confirm': 'test123',
+        request = self.get_request(
+            post={
+                "password": {
+                    "password": "test123",
+                    "password-confirm": "test123",
+                },
+                "csrf_token": "irrelevant but required",
             },
-            'csrf_token': 'irrelevant but required',
-        }, request_method='POST')
+            request_method="POST",
+        )
         request.add_flash = Mock()
         request.matchdict = Mock()
         get = Mock()
@@ -519,28 +560,32 @@ class TestForgotPasswordView(IntegrationTestBase):  # noqa
 
         def handle_password_reset(event):
             event.request.repo.flush()
+
         self.config.add_subscriber(handle_password_reset, PasswordResetEvent)
 
         view = ForgotPasswordView(request)
         response = view.reset_password()
 
-        assert user.check_password('test123')
+        assert user.check_password("test123")
         assert response.status_int == 302
 
     def test_reset_password_invalid_password(self):  # noqa
-        self.config.add_route('index', '/')
+        self.config.add_route("index", "/")
         self.config.registry.registerUtility(DummyMailer(), IMailer)
 
         user = self.create_users(count=1, activation=True)
         self.sas.flush()
 
-        request = self.get_request(post={
-            'Password': {
-                'Password': 't',
-                'Password-confirm': 't',
+        request = self.get_request(
+            post={
+                "Password": {
+                    "Password": "t",
+                    "Password-confirm": "t",
+                },
+                "csrf_token": "irrelevant but required",
             },
-            'csrf_token': 'irrelevant but required',
-        }, request_method='POST')
+            request_method="POST",
+        )
 
         request.matchdict = Mock()
         get = Mock()
@@ -552,16 +597,16 @@ class TestForgotPasswordView(IntegrationTestBase):  # noqa
         view = ForgotPasswordView(request)
         response = view.reset_password()
 
-        assert len(response['errors']) == 1
+        assert len(response["errors"]) == 1
 
     def test_reset_password_empty_password(self):  # noqa
         self.config.registry.registerUtility(DummyMailer(), IMailer)
-        self.config.add_route('index', '/')
+        self.config.add_route("index", "/")
 
         user = self.create_users(count=1, activation=True)
         self.sas.flush()
 
-        request = self.get_request(request_method='POST')
+        request = self.get_request(request_method="POST")
         request.matchdict = Mock()
         get = Mock()
         get.return_value = user.activation.code
@@ -571,11 +616,11 @@ class TestForgotPasswordView(IntegrationTestBase):  # noqa
         view = ForgotPasswordView(request)
         response = view.reset_password()
 
-        assert len(response['errors']) == 1
+        assert len(response["errors"]) == 1
 
     def test_invalid_reset_gets_404(self):  # noqa
         self.config.registry.registerUtility(DummyMailer(), IMailer)
-        self.config.add_route('index', '/')
+        self.config.add_route("index", "/")
 
         self.create_users(count=1, activation=True)
         self.sas.flush()
@@ -583,7 +628,7 @@ class TestForgotPasswordView(IntegrationTestBase):  # noqa
         request = self.get_request()
         request.matchdict = Mock()
         get = Mock()
-        get.return_value = 'wrong value'
+        get.return_value = "wrong value"
         request.matchdict.get = get
 
         request.user = None  # nobody is logged in
@@ -593,9 +638,8 @@ class TestForgotPasswordView(IntegrationTestBase):  # noqa
 
 
 class TestProfileView(IntegrationTestBase):  # noqa
-
     def test_profile_loads(self):  # noqa
-        self.config.add_route('index', '/')
+        self.config.add_route("index", "/")
 
         user = self.create_users(count=1)
         self.sas.flush()
@@ -612,10 +656,10 @@ class TestProfileView(IntegrationTestBase):  # noqa
 
         response = view.profile()
 
-        assert response.get('user', None) == user
+        assert response.get("user", None) == user
 
     def test_profile_bad_id(self):  # noqa
-        self.config.add_route('index', '/')
+        self.config.add_route("index", "/")
 
         self.create_users(count=1)
         self.sas.flush()
@@ -635,13 +679,14 @@ class TestProfileView(IntegrationTestBase):  # noqa
     def test_profile_update_profile_invalid(self):  # noqa
         from pluserable.interfaces import IProfileSchema
         from tests.schemas import ProfileSchema
+
         self.config.registry.registerUtility(ProfileSchema, IProfileSchema)
-        self.config.add_route('index', '/')
+        self.config.add_route("index", "/")
 
         user = self.create_users(count=1)
         self.sas.flush()
 
-        request = self.get_request(request_method='POST')
+        request = self.get_request(request_method="POST")
         request.user = user
 
         request.matchdict = Mock()
@@ -652,22 +697,28 @@ class TestProfileView(IntegrationTestBase):  # noqa
         # The code being tested
         response = ProfileView(request).edit_profile()
 
-        assert len(response['errors']) == 3
+        assert len(response["errors"]) == 3
 
     def test_profile_update_email(self):  # noqa
-        self.config.add_route('index', '/')
+        self.config.add_route("index", "/")
 
         user = self.create_users(count=1)
         self.sas.flush()
 
         def handle_profile_updated(event):
             event.request.repo.flush()
-        self.config.add_subscriber(handle_profile_updated, ProfileUpdatedEvent)
 
-        request = self.get_request(post={
-            'email': 'new_email@nasa.gov',
-            'csrf_token': 'irrelevant but required',
-        }, request_method='POST')
+        self.kerno.events.subscribe(
+            EventProfileUpdated, handle_profile_updated
+        )
+
+        request = self.get_request(
+            post={
+                "email": "new_email@nasa.gov",
+                "csrf_token": "irrelevant but required",
+            },
+            request_method="POST",
+        )
         request.add_flash = Mock()
         request.user = user
         request.matchdict = Mock()
@@ -679,24 +730,27 @@ class TestProfileView(IntegrationTestBase):  # noqa
         ProfileView(request).edit_profile()
 
         # Assertions
-        the_user = request.repo.q_user_by_id(user.id)
+        the_user = request.repo.get_user_by_id(user.id)
         assert the_user is user
-        assert the_user.email == 'new_email@nasa.gov'
-        assert user.check_password('science')
+        assert the_user.email == "new_email@nasa.gov"
+        assert user.check_password("science")
 
     def test_profile_update_password(self):  # noqa  # Happy
-        self.config.add_route('index', '/')
+        self.config.add_route("index", "/")
         user = self.create_users(count=1)
         self.sas.flush()
 
-        request = self.get_request(post={
-            'email': user.email,
-            'password': {
-                'password': 'new password',
-                'password-confirm': 'new password',
+        request = self.get_request(
+            post={
+                "email": user.email,
+                "password": {
+                    "password": "new password",
+                    "password-confirm": "new password",
+                },
+                "csrf_token": "irrelevant but required",
             },
-            'csrf_token': 'irrelevant but required',
-        }, request_method='POST')
+            request_method="POST",
+        )
         request.add_flash = Mock()
         request.user = user
 
@@ -706,13 +760,15 @@ class TestProfileView(IntegrationTestBase):  # noqa
         request.matchdict.get = get
 
         handle_profile_updated = Mock()
-        self.config.add_subscriber(handle_profile_updated, ProfileUpdatedEvent)
+        self.kerno.events.subscribe(
+            EventProfileUpdated, handle_profile_updated
+        )
 
         # The code being tested
         ProfileView(request).edit_profile()
 
         # Assertions
         assert user in request.repo.sas.dirty
-        assert user.email == 'carlsagan1@nasa.gov'
-        assert user.check_password('new password')
+        assert user.email == "carlsagan1@nasa.gov"
+        assert user.check_password("new password")
         assert handle_profile_updated.called
